summaryrefslogtreecommitdiffstats
path: root/chrome/browser/ui/browser.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/ui/browser.h')
-rw-r--r--chrome/browser/ui/browser.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/chrome/browser/ui/browser.h b/chrome/browser/ui/browser.h
index 0ab7df6..eaa2b57 100644
--- a/chrome/browser/ui/browser.h
+++ b/chrome/browser/ui/browser.h
@@ -961,9 +961,10 @@ class Browser : public TabHandlerDelegate,
void TabDetachedAtImpl(TabContentsWrapper* contents,
int index, DetachType type);
- // Create a preference dictionary for the provided application name. This is
- // done only once per application name / per session.
- static void RegisterAppPrefs(const std::string& app_name);
+ // Create a preference dictionary for the provided application name, in the
+ // given user profile. This is done only once per application name / per
+ // session / per user profile.
+ static void RegisterAppPrefs(const std::string& app_name, Profile* profile);
// Shared code between Reload() and ReloadIgnoringCache().
void ReloadInternal(WindowOpenDisposition disposition, bool ignore_cache);